@@ -93,10 +93,8 @@ sortConstrExprs <- function(parTable) {
       }
     }
 
-    if (!matchedAny) {
-      stop2("Unkown labels in constraints: ",
-            labels_i[!labels_i %in% definedLabels])
-    }
+    stopif(!matchedAny, "Unkown labels in constraints: ",
+           labels_i[!labels_i %in% definedLabels])
   }
 
   if (NROW(sortedRows) != NROW(rows)) {
@@ -104,10 +102,42 @@ sortConstrExprs <- function(parTable) {
              "attempting to estimate model with unsorted expressions")
     return(rows)
   }
+
   sortedRows
 }
 
 
+sortConstrExprsFinalPt <- function(parTable) {
+  if (!NROW(parTable)) return(NULL)
+
+  label <- NULL # R CMD check will complain that label and mod are not defined
+  mod   <- NULL # but they are defined in the parTable, and lazily evaluated
+                # defining them here stops R CMD check from complaining
+                # but doesn't change the behaviout of dplyr::rename()
+
+  # wrapr for sortConstrExprs meant to be used on the final output parTable
+  # not for the input parTable (e.g., mod -> label)
+  constrExprs <- sortConstrExprs(dplyr::rename(parTable, mod=label))
+  
+  if (is.null(constrExprs)) NULL else dplyr::rename(constrExprs, label=mod)
+}
+
+
+parTableLabelsToList <- function(parTable) {
+  parTable <- parTable[parTable$label != "", ]
+
+  labelList <- list()
+  for (i in seq_len(NROW(parTable))) {
+    val   <- parTable[i, "est"]
+    label <- parTable[i, "label"]
+
+    labelList[[label]] <- val
+  }
+
+  labelList
+}
+
+
 getVarsExpr <- function(expr) {
   tokens <- createTokensLine(getCharsLine(expr))
   tokens[vapply(tokens, FUN.VALUE = logical(1L), FUN = is.LavName)] |>
